#ifndef RAWMICROSLICEHEADERV0_H
#define RAWMICROSLICEHEADERV0_H
#include "DAQDataFormats/RawDAQData.h"
#include "DAQDataFormats/Macros.h"
#include "DAQDataFormats/BitFields.h"

/// It is requred to
///   1. include DAQDataFormats/DataFormatFirst.inc
///   2. define CURRENT_CLASS
///   3.    define CURRENT_CLASS_VERSION for version of the class
///      OR define LAST_CLASS_VERSION    for the main structure of the class
///   4. (optional) define CURRENT_FIELDS_SUB_NAMESPACE
///   5. include DAQDataFormats/DataFormatLast.inc
/// before the declaration of the DataFormat version class in the header.
#include "DAQDataFormats/DataFormatFirst.inc"
#define  CURRENT_CLASS                RawMicroSliceHeader
#define  CURRENT_CLASS_VERSION        0
#define  CURRENT_FIELDS_SUB_NAMESPACE rawmuhdr
#include "DAQDataFormats/DataFormatLast.inc"

/// CAUTION!!!!!
/// It is assumes that MicroSlice header always has a size of 1 for all versions

namespace daqdataformats {
     static const uint32_t RAWMICROSLICEHEADER_SIZE = 1;
     
     namespace  VERSION_NAMESPACE {
        namespace CURRENT_FIELDS_SUB_NAMESPACE {


            enum MicroSliceHeaderMASKS{
                    MASK_DataPresent    = 0x80000000,///< DP bit
                    MASK_MonteCarloFlag = 0x40000000,///< SIM bit. True if it's simuleted data
                    MASK_Extra          = 0x3FC00000,///< Extra bits (used for debugging purposes by Rick K)
                    MASK_Version        = 0x003E0000,///< Microslice header version
                    MASK_Timeout        = 0x00010000,///< Microslice Timeout bit
                    MASK_ByteCount      = 0x0000FFFF ///< Leading Byte count
            };
            enum MicroSliceHeaderWORDS {
                    WORD_DataPresent    = 0,///< DP bit
                    WORD_MonteCarloFlag = 0,///< SIM bit. True if it's simuleted data
                    WORD_Extra          = 0,///< Extra bits (used for debugging purposes by Rick K)
                    WORD_Version        = 0,///< Microslice header version
                    WORD_Timeout        = 0,///< Microslice Timeout bit
                    WORD_ByteCount      = 0 ///< Leading Byte count
            };

            DEFINE_SHIFT_FROM_MASK(DataPresent)
            DEFINE_SHIFT_FROM_MASK(MonteCarloFlag)
            DEFINE_SHIFT_FROM_MASK(Extra)
            DEFINE_SHIFT_FROM_MASK(Version)
            DEFINE_SHIFT_FROM_MASK(Timeout)
            DEFINE_SHIFT_FROM_MASK(ByteCount)
        };// end of namespace CURRENT_FIELDS_SUB_NAMESPACE


    class RawMicroSliceHeader: public PREVIOUS_VERSION_CLASS_NAME {
    
        public:
            RawMicroSliceHeader (const version_t);
            RawMicroSliceHeader (const RawMicroSliceHeader&);
            ~RawMicroSliceHeader(); ///< Destructor

            void     init    ();
            void     initSoft(); ///< initing without setting the version field
            using    PREVIOUS_VERSION_CLASS_NAME::print;
            void     print           (std::ostream& os=std::cout) const;
            uint32_t sizeofdata      () const { return RAWMICROSLICEHEADER_SIZE;}
            using    PREVIOUS_VERSION_CLASS_NAME::readData;
            void*    readData(const void* pointer){return RawDAQData::readDataGeneral(pointer);}

            /// CAUTION!!!!!
            /// It is  assume that these methods will
            /// be the same for all versions of MicroSlice Header
            IMPLEMENT_GET_AND_SET_BOOL(DataPresent)
            IMPLEMENT_GET_AND_SET_BOOL(MonteCarloFlag)
            IMPLEMENT_GET_AND_SET_BOOL(Timeout)
            IMPLEMENT_GET             (Version  , uint32_t)
            IMPLEMENT_GET_AND_SET     (ByteCount, uint32_t)
            bool     addByteCount(const uint32_t);
            bool     resetByteCount();
            uint32_t getMicroSliceSize() const;
            virtual bool setVersion(const version_t);

        protected:
            /// These methods are different for different
            /// versions of the MicroSlice header
            IMPLEMENT_FIRST_GET_AND_SET(Extra , uint32_t)
            INIT_FIRST_GET_AND_SET     (Status, uint32_t)

    };// end of RawMicroSliceHeader
}} // END NAMESPCE 

#endif /* RAWMICROSLICEHEADERV0_H */
