#ifndef RAWNANOSLICEV5_H
#define RAWNANOSLICEV5_H
#include "DAQDataFormats/RawNanoSliceV4.h"

/// It is requred to
///   1. include DAQDataFormats/DataFormatFirst.inc
///   2. define CURRENT_CLASS
///   3.    define CURRENT_CLASS_VERSION for version of the class
///      OR define LAST_CLASS_VERSION    for the main structure of the class
///   4. (optional) define CURRENT_FIELDS_SUB_NAMESPACE
///   5. include DAQDataFormats/DataFormatLast.inc
/// before the declaration of the DataFormat version class in the header.
#include "DAQDataFormats/DataFormatFirst.inc"
#define  CURRENT_CLASS                RawNanoSlice
#define  CURRENT_CLASS_VERSION        5
#define  CURRENT_FIELDS_SUB_NAMESPACE rawnano
#include "DAQDataFormats/DataFormatLast.inc"

namespace daqdataformats {

  namespace  VERSION_NAMESPACE {
        namespace CURRENT_FIELDS_SUB_NAMESPACE {

            static const uint32_t RAWNANOSLICE_SIZE = 12;

        };// end of namespace rawnano

  //! Class to hold the data from the FEBs in correct formats
  /*!
    The RawNanoSlice class is designed to mimic the format of the actual data
    block that the NOvA Front End6
    Boards (FEBS) produce when they detect a signal
    above the zero suppression threshold.
    
    The class supports general initialization with or with out data blocks as
    well as copyin style initialization for use with STL containers.
    
    Pack and unpack methods for the data rely on two types of structured data
    blocks that are provided in association with the class.
    
    The NanoSliceBlock structure breaks the raw data block out into its related
    high and low half words to give the headers, time stamps and pulseheight information
    
    The NanoSliceHeader structure further breaks out the header blocks into the
    individual data information parts.
  */

  class RawNanoSlice: public PREVIOUS_VERSION_CLASS_NAME {
    
        public:
      
            // Constructors
            RawNanoSlice (const version_t );
            RawNanoSlice (const NanoSlice&);
            RawNanoSlice (const RawNanoSlice&);
            /// Destructor
            ~RawNanoSlice();

            uint32_t sizeofdata  () const { return version5::rawnano::RAWNANOSLICE_SIZE;}


  };// end of RawNanoSlice
  
  
}} // END NAMESPCE daqdataformats
#endif /* RAWNANOSLICEV5_H */
