#ifndef DAQRAWTRIGGERRANGE_H
#define DAQRAWTRIGGERRANGE_H
#include "DAQDataFormats/RawTriggerRangeV0.h"
#include "DAQDataFormats/TriggerDefines.h"

/// It is requred to
///   1. include DAQDataFormats/DataFormatFirst.inc
///   2. define CURRENT_CLASS
///   3.    define CURRENT_CLASS_VERSION for version of the class
///      OR define LAST_CLASS_VERSION    for the main structure of the class
///   4. (optional) define CURRENT_FIELDS_SUB_NAMESPACE
///   5. include DAQDataFormats/DataFormatLast.inc
/// before the declaration of the DataFormat version class in the header.
#include "DAQDataFormats/DataFormatFirst.inc"
#define  CURRENT_CLASS                RawTriggerRange
#define  LAST_CLASS_VERSION           0
#define  CURRENT_FIELDS_SUB_NAMESPACE triggerrange
#include "DAQDataFormats/DataFormatLast.inc"

namespace daqdataformats {

    namespace CURRENT_FIELDS_SUB_NAMESPACE {
        static const version_t RAWTRIGGERRANGE_LATEST_VERSION = LAST_CLASS_VERSION;
    }


  //! Class to hold the data from the global trigger range in the correct format
  /*!
    The RawTriggerRange contains the width of the trigger gate in
    500 nsec units.

    The class supports general initialization with an internal or external
    data buffer as well as copyin style initialization for use with
    STL containers.
  */
  class RawTriggerRange: public PREVIOUS_VERSION_CLASS_NAME {

        public:
            RawTriggerRange(const version_t version = triggerrange::RAWTRIGGERRANGE_LATEST_VERSION);		                            //!< Constructor
            RawTriggerRange(const RawTriggerRange& copy_in);	    //!< Copyin Constructor
            RawTriggerRange(const void* buffer, const version_t version = rawdaqdataformat::DAQDATAFORMAT_UNKNOWN_VERSION);  //!< Constructor with data intialization
            ~RawTriggerRange();                                    //!< Destructor

            IMPLEMENT_MAIN_STANDARD

            IMPLEMENT_GET_MAIN        (Version       , uint32_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerLength, uint32_t)

            IMPLEMENT_FIGUREOUT_VERSION_STATIC(CURRENT_CLASS)

       protected:
            IMPLEMENT_SET_MAIN(Version  , uint32_t)
            bool             setFunctionPointers();

  };
  
  
} // END NAMESPCE daqdataformats
#endif /* DAQRAWTRIGGERRANGE_H */
