#ifndef DAQRAWTRIGGERTIME_H
#define DAQRAWTRIGGERTIME_H

#include "DAQDataFormats/RawTriggerTimeV0.h"
#include "DAQDataFormats/TriggerDefines.h"

/// It is requred to
///   1. include DAQDataFormats/DataFormatFirst.inc
///   2. define CURRENT_CLASS
///   3.    define CURRENT_CLASS_VERSION for version of the class
///      OR define LAST_CLASS_VERSION    for the main structure of the class
///   4. (optional) define CURRENT_FIELDS_SUB_NAMESPACE
///   5. include DAQDataFormats/DataFormatLast.inc
/// before the declaration of the DataFormat version class in the header.
#include "DAQDataFormats/DataFormatFirst.inc"
#define  CURRENT_CLASS                RawTriggerTime
#define  LAST_CLASS_VERSION           0
#define  CURRENT_FIELDS_SUB_NAMESPACE triggertime
#include "DAQDataFormats/DataFormatLast.inc"

namespace daqdataformats {

    namespace CURRENT_FIELDS_SUB_NAMESPACE {
        static const version_t RAWTRIGGERTIME_LATEST_VERSION = LAST_CLASS_VERSION;
    };

  //! Class to hold the data corresponding to the trigger mask
  /*!
    The RawTriggerTime contains the information on the type of trigger
    that is being issued.

    The class supports general initialization with an internal or external
    data buffer as well as copyin style initialization for use with
    STL containers.
  */
  class RawTriggerTime: public PREVIOUS_VERSION_CLASS_NAME {

        public:

            RawTriggerTime(const version_t version = CURRENT_FIELDS_SUB_NAMESPACE::RAWTRIGGERTIME_LATEST_VERSION);		                            //!< Constructor
            RawTriggerTime(const RawTriggerTime& copy_in);	    //!< Copyin Constructor
            RawTriggerTime(const void* buffer, const version_t version = rawdaqdataformat::DAQDATAFORMAT_UNKNOWN_VERSION);  //!< Constructor with data intialization
            ~RawTriggerTime();                                    //!< Destructor

            IMPLEMENT_MAIN_STANDARD

            IMPLEMENT_GET_MAIN        (Version               , uint32_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerTimeStampLow   , uint32_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerTimeStampHigh  , uint32_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerTimeStamp_sec  , uint32_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerTimeStamp_usec , uint32_t)
            IMPLEMENT_GET_AND_SET_MAIN(ClockSource           , uint32_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerOrigLength     , uint32_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerTimeStamp      , uint64_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerTimeStampTvUsec, suseconds_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerTimeStampTvSec , time_t)
            IMPLEMENT_GET_AND_SET_MAIN(TriggerTimeStampTv    , timeval)

            IMPLEMENT_FIGUREOUT_VERSION_STATIC(CURRENT_CLASS)

       protected:
            IMPLEMENT_SET_MAIN(Version  , uint32_t)
            bool             setFunctionPointers();

  };


} // END NAMESPACE daqdataformats
#endif /* DAQRAWTRIGGERTIME_H */
