#ifndef __DAQMSGERROR_HPP_
#define __DAQMSGERROR_HPP_

#include "getopt.h"
#include <string>
#include <sstream>
#include <iomanip>
#include <vector>
#include <fstream>

namespace novadaq {

  namespace messages {
    
    namespace error {
      
      namespace rc {

	/**
	 * Run Control Error Codes and Messages
	 *
	 * @author Jonathan Paley
	 * @version $Id: Error.h,v 1.19 2016/02/03 18:40:04 eflumerf Exp $
	 */

	enum errCode {
	  kOk, // 1
	  kNoResources,
	  kResourceNotFound,
	  kResourceUnselected,
	  kResourceNotReserved,
	  kNoRMSResponse,
	  kOpenFileFail,
	  kNoDCMs,
	  kNoBNEVBs,
	  kMissingURL, // 10
	  kResourceInOtherPartition,
	  kNoPartition,
	  kFail,
	  kNoStartTime,
	  kNoStopTime,
	  kNoShifter,
	  kNoRunType,
	  kGTOk,
	  kGTWarning, 
	  kGTError, // 20
	  kDLOk,
	  kDLWarning,
	  kDLError,	  
	  kCfgMgrOk,
	  kCfgMgrWarning,
	  kCfgMgrError,	  
	  kBNEVBsOk,
	  kBNEVBWarning,
	  kBNEVBError, 
	  kDCMsOk, // 30	  
	  kDCMWarning,
	  kDCMError,
	  kTDUOk, 
	  kTDUWarning,
	  kTDUError,
	  kMissedHeartbeat,
	  kDBDisabled,
	  kDCMUncommissioned,
	  kNoRunNumber,
	  kNErrors // 40
	};
	
	static const char* const errMsg[] = {
	  "Success",
	  "No resources found from Resource Manager",
	  "Resource not found",
	  "Resource not selected",
	  "Resource not reserved",
	  "Application failed to respond within timeout interval",
	  "Failed to open file",
	  "No DCM in resource list",
	  "No BNEVB in resource list",
	  "Missing URL",
	  "Resource already in another partition",
	  "Partition has not been established",
	  "Fail",
	  "No run start time",
	  "No run stop time",
	  "No shifter",
	  "No run type",
	  "GT Ok",
	  "GT Warning",
	  "GT Error",
	  "DL Ok",
	  "DL Warning",
	  "DL Error",
	  "CfgMgr Ok",
	  "CfgMgr Warning",
	  "CfgMgr Error",
	  "BNEVBs Ok",
	  "BNEVBs Warning",
	  "BNEVBs Error",
	  "DCMs Ok",
	  "DCMs Warning",
	  "DCMs Error",
	  "TDU Ok",
	  "TDU Warning",
	  "TDU Error",
	  "missed too many heartbeats",
	  "Log to database may not be disabled for a non-Test run",
	  "May not begin a Production run with an uncommissioned DCM",
	  "Unable to determine next run number, please check status of the database",
	  0
	  };

      }

      namespace gt {

      }

      namespace dl {
	enum errCode {
	  kOk, // 1
	  kExistingFileFound,
          kNErrors 
	};

        static const char* const errMsg[] = {
          "Ok",
          "DataLogger not responsive",
	  0
	};
      }

      namespace cfgmgr {

      }

      namespace bnevb {

      }

      namespace tdu {

      }

      namespace dcm {

	/**
	 * DCM Error Codes and Messages
	 *
	 * @author S. Kasahara
	 */

	enum errCode {
          kOk,
          kCtrlRegGeneralStatusError,
          kTimingCmdHistoryBufferError,
          kFEBLinkStatusError,
          kFEBErrorFlagRegisterError,
          kNoValidEVBConnections,
          kBrokenEVBConnection,
          kInvalidEVBConnection,
          kDataFlowHasStopped,
          kUnknownError,
          kNErrors 
	};
	
        static const char* const errMsg[] = {
          "Ok",
          "Ctrl Reg General Status Error. This is the catch-all for ANY DCM or FEB error that is not more specifically categorized.",
          "Timing Cmd History Buffer Error",
          "FEB Link Status Error",
          "FEB Error Flag Register Error",
          "No Valid EVB Connections",
          "Broken EVB Connection",
          "Invalid EVB Connection",
          "Data Flow Has Stopped",
          "Unknown Error",
	  0
        };

      }

      namespace appmgr {

	/**
	 * DAQ App Manager Error Codes and Messages
	 *
	 * @author J. Paley
	 */

	enum errCode {
          kOk,
          kProcessUnresponsive,
          kNErrors 
	};
	
        static const char* const errMsg[] = {
          "Ok",
          "Applicatin is Unresponsive",
	  0
        };

      }

      namespace ndm {

	/**
	 * NovaDAQMonitor Error Codes and Messages
	 *
	 * @author S. Kasahara
	 */

	enum errCode {
          kOk,
          kUnknownError,
          kNErrors 
	};
	
        static const char* const errMsg[] = {
          "Ok",
          "Unknown Error",
	  0
        };

      }

      namespace tdu {

      }



      // error handler messages from MsgAnalyzer
      namespace eh {

	enum errCode {
	  kOk,
	  kDCMReaderStopped,
	  kFEBTimestampDiff
	};

	static const char* const errMsg[] = {
	  "Ok",
	  "DCM Reader Stopped",
	  "FEB Timestamp Difference Error"
	};

      }


    }
  }
}

#endif
