#ifndef _NOVADAQ_BACKGROUND_PROCESS_H
#define _NOVADAQ_BACKGROUND_PROCESS_H

#include <string>
#include <NovaDAQUtilities/Runnable.h>
#include <boost/thread/thread.hpp>

namespace novadaq {

class BackgroundProcess : public novadaq::Runnable {

public:
    
    BackgroundProcess(std::string commandString, std::string description = "");
    ~BackgroundProcess();

    void waitForDone();
    bool timedWaitForDone(uint32_t microSeconds);
    int exitStatus();

    std::string getCommandString() {return _commandString;}
    std::string getDescription() {return _description;}
    std::string getStdoutText();
    std::string getStderrText();
    std::string getFormattedSummary();

    void run();
    void stop();

private:

    std::string _commandString;
    std::string _description;
    pid_t _childProcessId;

    // the thread that does the work for the process
    boost::thread* _workerThread;

    std::string _stdoutOutput;
    std::string _stderrOutput;
    int _exitStatus;
};

};  // end of namespace novadaq

#endif
