#ifndef _RMS_CLIENTLISTENERLOOP_H
#define _RMS_CLIENTLISTENERLOOP_H

#include <NovaDAQUtilities/Runnable.h>
#include <rms/util/LinkedBlockingQueue.h>
#include <rms/RmsMessageListener.h>
#include <rms/MessageFilter.h>

#include <boost/shared_ptr.hpp>

#include <string>

namespace gov {

namespace fnal {

namespace cd {

namespace rms {

/**
 * The ClientListenerLoop decouples receiveing messages from
 * the provider and sending them to any message listeners.
 *
 * @author Kurt Biery
 * @author Steve Foulkes
 * @version $Revision: 1.2 $ $Date: 2010/04/16 18:40:23 $
 */

class ClientListenerLoop : public novadaq::Runnable {
 public:
    ClientListenerLoop(util::LinkedBlockingQueue <boost::shared_ptr<std::string> > *inputQueue);
    ~ClientListenerLoop();

    void run();
    void stop();
    
    void setMessageListener(RmsMessageListener *listener);
    void setMessageFilter(MessageFilter *filter);
    
 private:
    /** 
     * The queue that we will be pulling messages off of. 
     */
    util::LinkedBlockingQueue <boost::shared_ptr<std::string> > *_inputQueue;
 
    /**
     * The listener that we will be sending messages to. 
     */
    RmsMessageListener *_clientListener;
 
    /** 
     * The filter that we will be running messages through to determine if 
     * they are relevant to the listener. 
     */
    MessageFilter *_messageFilter;
};
 
};  // end of namespace rms
 
};  // end of namespace cd

};  // end of namespace fnal

};  // end of namespace gov

#endif
