#ifndef _RMS_MESSAGEFILTER_H
#define _RMS_MESSAGEFILTER_H

#include <rms/base/RmsMessage.h>

#include <boost/shared_ptr.hpp>

namespace gov {

namespace fnal {

namespace cd {

namespace rms {

/**
 * This interface is implemented by the Producer and Consumer
 * classes.  The result of the verify method is used to determine
 * if a message is relevant to a particular Consumer or Producer.
 *
 * @author Kurt Biery
 * @author Steve Foulkes
 * @version $Revision: 1.1.1.1 $ $Date: 2009/10/09 20:03:00 $
 */

class MessageFilter {
 public:
  
    /**
     * Virtual destructor to quiet compiler warnings.
     */
    virtual ~MessageFilter() { 
        return; 
    }
    
    /**
     * Given an RmsMessage, verify that it matches the filter.
     *
     * @param message The message received from the provider
     *
     * @return True if the message matches the filter, false otherwise.
     */
    virtual bool verify(boost::shared_ptr<base::RmsMessage> message) { 
        return false; 
    }
};
 
};  // end of namespace rms

};  // end of namespace cd

};  // end of namespace fnal

};  // end of namespace gov

#endif
