#include "DAQDataFormats/RawEventHeaderV0.h"
#include <boost/format.hpp>

/// It is requred to
///   1. include DAQDataFormats/DataFormatFirst.inc
///   2. define CURRENT_CLASS
///   3.    define CURRENT_CLASS_VERSION for version of the class
///      OR define LAST_CLASS_VERSION    for the main structure of the class
///   4. (optional) define CURRENT_FIELDS_SUB_NAMESPACE
///   5. include DAQDataFormats/DataFormatLast.inc
/// before the declaration of the DataFormat version class in the header.
#include "DAQDataFormats/DataFormatFirst.inc"
#define  CURRENT_CLASS                RawEventHeader
#define  CURRENT_CLASS_VERSION        0
#define  CURRENT_FIELDS_SUB_NAMESPACE raweventhdr
#include "DAQDataFormats/DataFormatLast.inc"

namespace daqdataformats{
namespace VERSION_NAMESPACE{

//------------------------------------------------------------------------------
// Default constructor
RawEventHeader::RawEventHeader(const version_t version):
             RawDAQData(version)
            ,ZEROOUT_GET_AND_SET(MarkerLeft      )
            ,ZEROOUT_GET_AND_SET(MarkerRight     )
            ,ZEROOUT_GET_AND_SET(Version         )
            ,ZEROOUT_GET_AND_SET(DataLoggerID    )
            ,ZEROOUT_GET_AND_SET(RunNumber       )
            ,ZEROOUT_GET_AND_SET(RunType         )
            ,ZEROOUT_GET_AND_SET(ConfigIDX       )
            ,ZEROOUT_GET_AND_SET(Partition       )
            ,ZEROOUT_GET_AND_SET(Subrun          )
            ,ZEROOUT_GET_AND_SET(EventNumberLo   )
            ,ZEROOUT_GET_AND_SET(EventNumberHi   )
            ,ZEROOUT_GET_AND_SET(EventType       )
            ,ZEROOUT_GET_AND_SET(EventSize       )
            ,ZEROOUT_GET_AND_SET(DataBlockNumber )
            ,ZEROOUT_GET_AND_SET(MonteCarloFlag)
            ,ZEROOUT_IS_AND_SET (CRCCalculationUsed)
            ,ZEROOUT_IS_AND_SET (EventIncomplete)
            ,ZEROOUT_FUNCTION(addEventSize          )
            ,ZEROOUT_FUNCTION(advanceEventNumber    )
            ,ZEROOUT_FUNCTION(advanceDataBlockNumber)
            ,ZEROOUT_GET_AND_SET(EventNumber)
{ }

//------------------------------------------------------------------------------
RawEventHeader::RawEventHeader(const RawEventHeader& copyin):
             RawDAQData(copyin)
            ,DEEPCOPY_GET_AND_SET(MarkerLeft      )
            ,DEEPCOPY_GET_AND_SET(MarkerRight     )
            ,DEEPCOPY_GET_AND_SET(Version         )
            ,DEEPCOPY_GET_AND_SET(DataLoggerID    )
            ,DEEPCOPY_GET_AND_SET(RunNumber       )
            ,DEEPCOPY_GET_AND_SET(RunType         )
            ,DEEPCOPY_GET_AND_SET(ConfigIDX       )
            ,DEEPCOPY_GET_AND_SET(Partition       )
            ,DEEPCOPY_GET_AND_SET(Subrun          )
            ,DEEPCOPY_GET_AND_SET(EventNumberLo   )
            ,DEEPCOPY_GET_AND_SET(EventNumberHi   )
            ,DEEPCOPY_GET_AND_SET(EventType       )
            ,DEEPCOPY_GET_AND_SET(EventSize       )
            ,DEEPCOPY_GET_AND_SET(DataBlockNumber )
            ,DEEPCOPY_GET_AND_SET(MonteCarloFlag)
            ,DEEPCOPY_IS_AND_SET (CRCCalculationUsed)
            ,DEEPCOPY_IS_AND_SET (EventIncomplete)
            ,DEEPCOPY_FUNCTION(addEventSize          )
            ,DEEPCOPY_FUNCTION(advanceEventNumber    )
            ,DEEPCOPY_FUNCTION(advanceDataBlockNumber)
            ,DEEPCOPY_GET_AND_SET(EventNumber)
{ }

//------------------------------------------------------------------------------
// Destructor
RawEventHeader::~RawEventHeader() { }

//------------------------------------------------------------------------------
// Initialization of data members
void RawEventHeader::init(){
    setVersion (_version);
    setMarkerLeft (daqdataformats::CURRENT_FIELDS_SUB_NAMESPACE::Marker_value[0]);
    setMarkerRight(daqdataformats::CURRENT_FIELDS_SUB_NAMESPACE::Marker_value[1]);
    setEventSize(EXECUTE_FUNCTION(sizeofdata)());
}

//------------------------------------------------------------------------------
uint64_t RawEventHeader::getEventNumber()         const  { 
    return getUint64_t(EXECUTE_FUNCTION(getEventNumberLo)(), EXECUTE_FUNCTION(getEventNumberHi)());
}
//------------------------------------------------------------------------------
bool     RawEventHeader::setEventNumber (const uint64_t event) {
      uint32_t low, high;
      getLoAndHi(event, low, high);

      EXECUTE_FUNCTION(setEventNumberHi)(high);
      RETURN_FUNCTION(setEventNumberLo)(low);
}

//------------------------------------------------------------------------------
bool RawEventHeader::addEventSize  (const uint32_t size) {RETURN_FUNCTION(setEventSize)(EXECUTE_FUNCTION(getEventSize)() + size);}
bool RawEventHeader::advanceDataBlockNumber()            {RETURN_FUNCTION(setDataBlockNumber)(EXECUTE_FUNCTION(getDataBlockNumber)() + 1);}
bool RawEventHeader::advanceEventNumber()                {RETURN_FUNCTION(setEventNumber)(EXECUTE_FUNCTION(getEventNumber)() + 1);}


//------------------------------------------------------------------------------
version_t RawEventHeader::getTailVersion() const {return CURRENT_FIELDS_SUB_NAMESPACE::VERSION_Tail;}

//------------------------------------------------------------------------------
// Print the MilliSlice header information
void RawEventHeader::print(std::ostream& os) const{
    os<<"\nRawEvent Header:";
    os<<boost::format(" MarkerLeft=%u"          ) % EXECUTE_FUNCTION(getMarkerLeft)();   //! MilliSlice header delimiter
    os<<boost::format(" MarkerRight=%u"         ) % EXECUTE_FUNCTION(getMarkerRight)();  //! MilliSlice header delimiter
    os<<boost::format(" Version=%u"             ) % EXECUTE_FUNCTION(getVersion)();      //! Version number for the MilliSlice event builder
    os<<boost::format(" DataLoggerID=%u"        ) % EXECUTE_FUNCTION(getDataLoggerID)();
    os<<boost::format(" RunNumber=%u"           ) % EXECUTE_FUNCTION(getRunNumber)();
    os<<boost::format(" RunType=%u"             ) % EXECUTE_FUNCTION(getRunType)();
    os<<boost::format(" ConfigIDX=%u"           ) % EXECUTE_FUNCTION(getConfigIDX)();
    os<<boost::format(" Partition=%u"           ) % EXECUTE_FUNCTION(getPartition)();
    os<<boost::format(" Subrun=%u"              ) % EXECUTE_FUNCTION(getSubrun)();
    os<<boost::format(" EventNumberLo=%u"       ) % EXECUTE_FUNCTION(getEventNumberLo)();
    os<<boost::format(" EventNumberHi=%u"       ) % EXECUTE_FUNCTION(getEventNumberHi)();
    os<<boost::format(" EventType=%u"           ) % EXECUTE_FUNCTION(getEventType)();
    os<<boost::format(" EventSize=%u"           ) % EXECUTE_FUNCTION(getEventSize)();
    os<<boost::format(" DataBlockNumber=%u"     ) % EXECUTE_FUNCTION(getDataBlockNumber)();
    os<<boost::format(" isEventIncomplete=%u"   ) % EXECUTE_FUNCTION(isEventIncomplete)();
    os<<boost::format(" MonteCarloFlag=%u"      ) % EXECUTE_FUNCTION(getMonteCarloFlag)();
    os<<boost::format(" isCRCCalculationUsed=%u") % EXECUTE_FUNCTION(isCRCCalculationUsed)();

    const uint32_t size_of_data = EXECUTE_FUNCTION(sizeofdata)();

    os<<"\nRAW:";
    for(uint32_t i = 0; i < size_of_data; ++i){
        os<<boost::format(" ");
        printWord(i, false, os);
    }

    os<<"\nRAW:";
    for(uint32_t i = 0; i < size_of_data; ++i){
        os<<boost::format("\n");
        printWord(i, true, os);
    }

}


}}
