#include <DatabaseUtils/DAQAppMgr/ConfiguredApplicationTypes.h>
#include <NovaDatabase/Table.h>
#include <NovaDatabase/Util.h>
#include <boost/shared_ptr.hpp>

namespace NOVADB = nova::database;

namespace dbutils {
namespace daqappmgr {

/**
 * Creates a new instance based on the specified detector name
 * (NDOS, NearDet, FarDet).
 */
ConfiguredApplicationTypes::
ConfiguredApplicationTypes(const std::string& detectorName,
                           int partitionNumber,
                           const bool& useDBData)
{
    _hasValidData = false;
    std::string fname;
}

/**
 * Fetches the application type instance with the specified name.
 */
boost::shared_ptr<ApplicationType> ConfiguredApplicationTypes::
getTypeByName(const std::string& typeName) const
{
    boost::shared_ptr<ApplicationType> typePtr;
    if (! _hasValidData) {return typePtr;}

    for (int idx = 0; idx < (int) _typeList.size(); ++idx) {
        if (_typeList[idx]->getTypeName() == typeName) {
            typePtr = _typeList[idx];
            break;
        }
    }

    return typePtr;
}

/**
 * Adds the specified type to the list
 */
void ConfiguredApplicationTypes::
_addApplicationType(boost::shared_ptr<ApplicationType> appType)
{
    if (appType.get() == 0) {return;}

    _hasValidData = true;

    _typeList.push_back(appType);
}

};  // end of namespace daqappmgr
};  // end of namespace dbutils
